@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -68,6 +68,15 @@ void PhoneWidgetLister::storeContact(KContacts::Addressee &contact) const
     contact.setPhoneNumbers(phoneNumbers);
 }
 
+void PhoneWidgetLister::setReadOnly(bool readOnly)
+{
+    const QList<QWidget *> widgetList = widgets();
+    for (QWidget *widget : widgetList) {
+        PhoneWidget *w = qobject_cast<PhoneWidget *>(widget);
+        w->setReadOnly(readOnly);
+    }
+}
+
 QWidget *PhoneWidgetLister::createWidget(QWidget *parent)
 {
     PhoneWidget *w = new PhoneWidget(parent);
